@@ -16,7 +16,7 @@ def _get_extract_func(key: str):
 
 
 @api_request("music.trackInfo.UniformRuleCtrl", "CgiGetTrackInfo")
-async def query_song(value: list[str] | list[int]):
+async def query_song(value: list[int] | list[str]):
     """根据 id 或 mid 获取歌曲信息
 
     Args:
@@ -114,6 +114,7 @@ class EncryptedSongFileType(BaseSongFileType):
 async def get_song_urls(
     mid: list[str],
     file_type: SongFileType = SongFileType.MP3_128,
+    *,
     credential: Credential | None = None,
 ) -> dict[str, str]: ...
 
@@ -122,6 +123,7 @@ async def get_song_urls(
 async def get_song_urls(
     mid: list[str],
     file_type: EncryptedSongFileType,
+    *,
     credential: Credential | None = None,
 ) -> dict[str, tuple[str, str]]: ...
 
@@ -129,6 +131,7 @@ async def get_song_urls(
 async def get_song_urls(
     mid: list[str],
     file_type: SongFileType | EncryptedSongFileType = SongFileType.MP3_128,
+    *,
     credential: Credential | None = None,
 ) -> dict[str, str] | dict[str, tuple[str, str]]:
     """获取歌曲文件链接
@@ -156,14 +159,16 @@ async def get_song_urls(
         urls = {}
         data = res["midurlinfo"]
         for info in data:
-            song_url = domain + info["wifiurl"] if info["wifiurl"] else ""
+            song_url = (
+                domain + info.get("purl") or info.get("wifiurl") if info.get("purl") or info.get("wifiurl") else ""
+            )
             if not encrypted:
                 urls[info["songmid"]] = song_url
             else:
                 urls[info["songmid"]] = (song_url, info["ekey"])
         return urls
 
-    rg = RequestGroup(credential=credential)
+    rg = RequestGroup(common={"ct": "19"}, credential=credential)
     for mid in mid_list:
         # 构造请求参数
         file_name = [f"{file_type.s}{_}{_}{file_type.e}" for _ in mid]
@@ -178,7 +183,6 @@ async def get_song_urls(
             api_data[1],
             params=params,
             credential=credential,
-            exclude_params=["guid"],
         )
         req.processor = _processor
         rg.add_request(req)
@@ -190,12 +194,7 @@ async def get_song_urls(
     return result
 
 
-@api_request(
-    "music.vkey.GetVkey",
-    "UrlGetVkey",
-    exclude_params=["guid"],
-    cacheable=False,
-)
+@api_request("music.vkey.GetVkey", "UrlGetVkey")
 async def get_try_url(mid: str, vs: str):
     """获取试听文件链接
 
@@ -213,7 +212,7 @@ async def get_try_url(mid: str, vs: str):
         "guid": get_guid(),
         "songmid": [mid],
         "songtype": [1],
-    }, lambda res: f"https://isure.stream.qqmusic.qq.com/{url}" if (url := res["midurlinfo"][0]["wifiurl"]) else ""
+    }, lambda res: f"https://isure.stream.qqmusic.qq.com/{url}" if (url := res["midurlinfo"][0]["wifiurl"]) else None
 
 
 @api_request("music.pf_song_detail_svr", "get_song_detail_yqq")
