@@ -5,16 +5,12 @@ import logging
 from typing import TypedDict
 
 import httpx
-import orjson as json
-from aiocache import Cache
-from aiocache.serializers import BaseSerializer
 
 from .credential import Credential
 from .qimei import get_qimei
 
 # 配置日志记录器
 logger = logging.getLogger(__name__)
-_session_counter = 0
 
 
 class ApiConfig(TypedDict):
@@ -27,28 +23,12 @@ class ApiConfig(TypedDict):
     enc_endpoint: str
 
 
-class ORJsonSerializer(BaseSerializer):
-    """Transform data to json string with json.dumps and json.loads to retrieve it back."""
-
-    def dumps(self, value):
-        """Serialize the received value using ``json.dumps``."""
-        return json.dumps(value, option=json.OPT_NON_STR_KEYS).decode()
-
-    def loads(self, value):
-        """Deserialize value using ``json.loads``."""
-        if value is None:
-            return None
-        return json.loads(value)
-
-
 class Session(httpx.AsyncClient):
     """Session 类,用于管理 QQ 音乐的登录态和 API 请求
 
     Args:
         credential: 全局凭证,每个请求都将使用.
         enable_sign: 是否启用加密接口
-        enable_cache: 是否启用请求缓存
-        cache_ttl: 缓存过期时间
     """
 
     HOST = "y.qq.com"
@@ -59,8 +39,6 @@ class Session(httpx.AsyncClient):
         *,
         credential: Credential | None = None,
         enable_sign: bool = False,
-        enable_cache: bool = True,
-        cache_ttl: int = 120,
         http2: bool = True,
         **kwargs,
     ) -> None:
@@ -79,16 +57,8 @@ class Session(httpx.AsyncClient):
             endpoint="https://u.y.qq.com/cgi-bin/musicu.fcg",
             enc_endpoint="https://u.y.qq.com/cgi-bin/musics.fcg",
         )
-        self.enable_cache = enable_cache
-        self._cache = Cache(serializer=ORJsonSerializer(), ttl=cache_ttl)
         self.qimei = get_qimei(self.api_config["version"])["q36"]
 
-    async def clear_cache(self):
-        """清除API请求缓存"""
-        if not self.enable_cache:
-            return
-        await self._cache.clear()
-
     async def __aenter__(self) -> "Session":
         """进入 async with 上下文时调用"""
         self._previous_session = _session_context.set(self)
