@@ -5,6 +5,7 @@ from qqmusic_api.login import (
     PhoneLoginEvents,
     QRCodeLoginEvents,
     QRLoginType,
+    check_mobile_qr,
     check_qrcode,
     get_qrcode,
     phone_authorize,
@@ -17,13 +18,20 @@ pytestmark = pytest.mark.asyncio(loop_scope="session")
 async def test_qq_login():
     qr = await get_qrcode(QRLoginType.QQ)
     state, _ = await check_qrcode(qr)
-    assert state in [QRCodeLoginEvents.SCAN]
+    assert state == QRCodeLoginEvents.SCAN
 
 
 async def test_wx_login():
     qr = await get_qrcode(QRLoginType.WX)
     state, _ = await check_qrcode(qr)
-    assert state in [QRCodeLoginEvents.SCAN]
+    assert state == QRCodeLoginEvents.SCAN
+
+
+async def test_mobile_login():
+    qr = await get_qrcode(QRLoginType.MOBILE)
+    async for state, _ in check_mobile_qr(qr):
+        assert state == QRCodeLoginEvents.SCAN
+        break
 
 
 async def test_phone_login():
